@@ -1,4 +1,4 @@
-from datetime import date
+from datetime import date, datetime
 from cc_py_commons.loads.load_schema import LoadSchema
 
 def execute(freight_hub_json):
@@ -14,6 +14,6 @@ def execute(freight_hub_json):
 
   available_time = freight_hub_json.get('availableTime')
   if available_time:
-    freight_hub_json_copy['availableTime'] = date.fromtimestamp(int(available_time)/1000).isoformat()
+    freight_hub_json_copy['availableTime'] = datetime.fromtimestamp(int(available_time)/1000).isoformat()
 
   return LoadSchema().load(freight_hub_json_copy)
