@@ -57,5 +57,7 @@ def from_load(load):
 	trans_data['freight_hub_load_id'] = load.id
 	if load.special_instructions:
 		trans_data['comments'] = load.special_instructions
+	if load.linear_feet:
+		trans_data['linear_feet'] = load.linear_feet
 	transaction = Transaction(**trans_data)
 	return transaction
